#! /usr/bin/env node

const path = require('path')
const Artisanft = require('artisanft')

console.log()
console.log('\x1b[34m', '**************************************************************', '\x1b[0m')
console.log('\x1b[36m', '******************** Welcome to Ideo Node ********************', '\x1b[0m')
console.log('\x1b[34m', '**************************************************************', '\x1b[0m')
console.log()

let projectName = process.argv[2] || 'my-project'

// presentation
Artisanft.Logger.logTask('init')
Artisanft.Logger.logInfo('Initialize a new project inside the ' + projectName + ' path.')

// create the project directory
Artisanft.Logger.logActionInit('Create the project directory')
Artisanft.Command.runSync('mkdir ' + projectName)
Artisanft.Logger.logActionEnd('Create the project directory')

// initialize server project
Artisanft.Logger.logActionInit('Create the package.json')
Artisanft.Command.runSync('cd ' + projectName + ' && npm init -y')
Artisanft.Logger.logActionEnd('Create the package.json')

// // add description
Artisanft.Logger.logActionInit('Add description to the package.json')
Artisanft.PackageJson.addDescriptionSync('An awesome node project!', projectName)
Artisanft.Logger.logActionEnd('Add description to the package.json')

// // add repository fields
Artisanft.Logger.logActionInit('Add repository fields to the package.json')
Artisanft.PackageJson.addRepositoryFieldsSync('git', 'http://awesomenodeproject.com', projectName)
Artisanft.Logger.logActionEnd('Add repository fields to the package.json')

// add MIT license
Artisanft.Logger.logActionInit('Add MIT license to the package.json')
Artisanft.PackageJson.addLicenseSync('MIT', projectName)
Artisanft.Logger.logActionEnd('Add MIT license to the package.json')

// add engines
Artisanft.Logger.logActionInit('Add engines to the package.json')
Artisanft.PackageJson.addEngineSync('node', '>8.0.0', projectName)
Artisanft.Logger.logActionEnd('Add engines to the package.json')

// install local dev dependencies
Artisanft.Logger.logActionInit('Install local dev dependencies')
// TODO: Take the list from external resource
Artisanft.Npm.installDevSync('autoprefixer jsdoc jest nodemon browser-sync cross-env npm-run-all rimraf babel-loader@8.0.0-beta.0 @babel/core @babel/preset-env babel-eslint babel-loader webpack css-loader extract-text-webpack-plugin file-loader node-sass postcss-loader sass-loader scss-loader style-loader url-loader', projectName)
Artisanft.Npm.installDevSync('ideonetwork/ideo-node-generator', projectName)
Artisanft.Logger.logActionEnd('Install local dev dependencies')

// copy template files
Artisanft.Logger.logActionInit('Copy template files')
Artisanft.FileSystem.copyAllSync(path.join(__dirname, '../templates/init'), projectName)
Artisanft.Logger.logActionEnd('Copy template files')

// install express dependencies
Artisanft.Logger.logActionInit('Install express dependencies')
Artisanft.Npm.installSync('express body-parser morgan helmet compression cors pug', projectName + '/lib/express')
Artisanft.Logger.logActionEnd('Install express dependencies')

// add custom scripts
Artisanft.Logger.logActionInit('Add scripts to package.json')

Artisanft.PackageJson.addScriptSync('start', 'node app.js', projectName)
Artisanft.PackageJson.addScriptSync('test', 'jest', projectName)
Artisanft.PackageJson.addScriptSync('doc', 'jsdoc -r -c ./doc/conf.json', projectName)
Artisanft.PackageJson.addScriptSync('clean', 'rimraf public/assets', projectName)
Artisanft.PackageJson.addScriptSync('build', 'webpack --hide-modules', projectName)
Artisanft.PackageJson.addScriptSync('watch', 'npm run build -- --watch', projectName)
Artisanft.PackageJson.addScriptSync('serve:dev', 'nodemon app.js --ignore app/assets/ --ignore public/', projectName)
Artisanft.PackageJson.addScriptSync('start:dev', 'npm-run-all clean build -p watch serve:dev', projectName)
Artisanft.PackageJson.addScriptSync('preinstall', 'node ./bin/preinstall', projectName)

Artisanft.Logger.logActionEnd('Add scripts to package.json')
