const EventEmitter = require('events')

/**
 * @class Operation
 */
class Operation extends EventEmitter {

  constructor (props = {}) {
    super()
    this.props = props
  }

  /**
   * @static @function setEvents
   * @param {array} events 
   */
  static setEvents(events) {
    Object.defineProperty(this.prototype, 'events', {
      value: events.reduce((object, event) => {
        object[event] = event
        return object
      }, Object.create(null))
    })
  }

  /**
   * @function on
   * @param {string} event 
   * @param {function} handler 
   */
  on (event, handler) {
    if (this.events[event]) {
      return this.addListener(event, handler)
    }

    throw new Error(`Invalid event "${event}" listened for operation ${this.constructor.name}.`)
  }

  /**
   * @function emit
   * @param {string} event 
   */
  emit(event) {
    if (this.events[event]) {
      super.emit(event)
      return
    }

    throw new Error(`Invalid event "${event}" emitted for operation ${this.constructor.name}.`)
  }

  /**
   * @function run
   */
  run () {
    throw new Error(`The run() method should be implemented for ${this.constructor.name} operation.`)
  }

}

module.exports = Operation
