const express = require('express')

const cors = require('./configs/cors')
const compression = require('./configs/compression')
const bodyParser = require('./configs/bodyParser')
const helmet = require('./configs/helmet')
const morgan = require('./configs/morgan')

const config = require('../../config')

// Initialize express app.
const expressApp = express()

// Add pug to render views.
expressApp.set('view engine', 'pug')
expressApp.set('views', `${config.root}/app/views`)

// Add public files path.
expressApp.use(express.static('public'))

// Add middleware to permit cors requests.
expressApp.use(cors)

// Add requests compression.
expressApp.use(compression)

// Add body-parser to parse body content.
expressApp.use(bodyParser.urlencoded)
expressApp.use(bodyParser.json)

// Add helmet to secure requests.
expressApp.use(helmet)

if (config.environment === 'development') {
  // Add middleware to log requests.
  expressApp.use(morgan)
}

module.exports = expressApp
