var webpack = require('webpack')
const ExtractTextPlugin = require('extract-text-webpack-plugin')
const config = require('./config')
const isDev = config.environment === 'development'

module.exports = {
  target: 'web',
  devtool: isDev ? 'source-map' : false,
  entry: [
    __dirname + '/app/assets/js/main.js',
    __dirname + '/app/assets/css/main.scss'
  ],
  output: {
    path: __dirname + '/public/assets/',
    filename: 'main.js',
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules/,
        options: {
          presets: ['@babel/preset-env'],
        },
      },
      {
        test: /\.(css|scss)$/i,
        loader: ExtractTextPlugin.extract({
          use: [{
            loader: 'css-loader',
            options: {
              minimize: !isDev,
              sourceMap: isDev,
            },
          },
          {
            loader: 'postcss-loader',
            options: {
              ident: 'postcss',
              plugins: () => [
                require('autoprefixer')(),
              ],
              sourceMap: true,
            },
          },
          {
            loader: 'sass-loader',
            options: {
              minimize: !isDev,
              sourceMap: isDev,
            },
          }],
          fallback: 'style-loader',
        }),
      },
      {
        test: /\.(otf|eot|ttf|woff)/,
        loader: 'url-loader?limit=8192',
      },
    ],
  },
  resolve: {
    extensions: ['.js', '.css', '.scss'],
  },
  plugins: isDev ?
    [
      new webpack.optimize.OccurrenceOrderPlugin(true),
      new webpack.DefinePlugin({
        'env': JSON.stringify(config.environment)
      }),
      new ExtractTextPlugin({
        filename: '[name].css',
        allChunks: true,
        disable: false,
      }),
    ] :
    [
      new webpack.optimize.OccurrenceOrderPlugin(true),
      new webpack.DefinePlugin({
        'env': JSON.stringify(config.environment)
      }),
      new webpack.optimize.UglifyJsPlugin({
        compress: {
          screw_ie8: true,
          warnings: false,
        },
        sourcemap: false,
        minimize: true,
        mangle: { except: ['$super', '$', 'exports', 'require', '$q', '$ocLazyLoad'] },
      }),
      new ExtractTextPlugin({
        filename: '[name].css',
        allChunks: true,
        disable: isDev,
      }),
    ]
}

